=======
Roadmap
=======

.. admonition:: Description

   Roadmap development is driven by client needs and partner investments,
   in alignment with our long-term vision.
   If you're interested in prioritizing certain features, please contact us at hello@quaive.com.

1. Mercury (spring 2015) - Community Edition Released
-----------------------------------------------------

* Personal dashboard
* Activity Streams
* Team spaces

2. Venus (fall 2015) - Community Edition Released
-------------------------------------------------

* Faceted search
* Document structures / wiki
* Personal profiles
* Adaptive case management


3. Gaia (summer 2016) - Enterprise Edition Released
---------------------------------------------------

* Document-level activity stream
* Follow tags
* Stream edit/delete moderation controls
* Case management reporting app
* Security audit app

4. Mars (winter 2016/2017) - under development
----------------------------------------------   

* Direct messaging
* Taxonomies
* Contacts/groups app
* News hub
* Notification center

Planned
-------

* Calendaring
* Generalized task management
* Machine learning integration
* Personalized search
